Developer guide
===============

Summary
----------

Development is based on `Vincent Driessen's branching model`_, with a
stable master branch and active develop branch. Use the issue tracker
to submit bug reports and post feature requests. Please submit pull
requests via separate feature branches.

Setting up a local copy
-------------------------

See installation section :ref:`installation-from-sources`.

.. _Vincent Driessen's branching model: http://nvie.com/posts/a-successful-git-branching-model/
